Class: Aws::Route53Domains::Types::GetOperationDetailRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Domains::Types::GetOperationDetailRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53domains/types.rb
Overview
The [GetOperationDetail] request includes the following element.
[1]: docs.aws.amazon.com/Route53/latest/APIReference/API_domains_GetOperationDetail.html
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#operation_id ⇒ String
The identifier for the operation for which you want to get the status.
Instance Attribute Details
#operation_id ⇒ String
The identifier for the operation for which you want to get the status. Route 53 returned the identifier in the response to the original request.
1864 1865 1866 1867 1868 |
# File 'lib/aws-sdk-route53domains/types.rb', line 1864 class GetOperationDetailRequest < Struct.new( :operation_id) SENSITIVE = [] include Aws::Structure end |