Class: Aws::Route53Domains::Types::ListDomainsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Domains::Types::ListDomainsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53domains/types.rb
Overview
The ListDomains request includes the following elements.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#filter_conditions ⇒ Array<Types::FilterCondition>
A complex type that contains information about the filters applied during the
ListDomainsrequest. -
#marker ⇒ String
For an initial request for a list of domains, omit this element.
-
#max_items ⇒ Integer
Number of domains to be returned.
-
#sort_condition ⇒ Types::SortCondition
A complex type that contains information about the requested ordering of domains in the returned list.
Instance Attribute Details
#filter_conditions ⇒ Array<Types::FilterCondition>
A complex type that contains information about the filters applied
during the ListDomains request. The filter conditions can include
domain name and domain expiration.
1995 1996 1997 1998 1999 2000 2001 2002 |
# File 'lib/aws-sdk-route53domains/types.rb', line 1995 class ListDomainsRequest < Struct.new( :filter_conditions, :sort_condition, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#marker ⇒ String
For an initial request for a list of domains, omit this element. If
the number of domains that are associated with the current Amazon
Web Services account is greater than the value that you specified
for MaxItems, you can use Marker to return additional domains.
Get the value of NextPageMarker from the previous response, and
submit another request that includes the value of NextPageMarker
in the Marker element.
Constraints: The marker must match the value specified in the previous request.
1995 1996 1997 1998 1999 2000 2001 2002 |
# File 'lib/aws-sdk-route53domains/types.rb', line 1995 class ListDomainsRequest < Struct.new( :filter_conditions, :sort_condition, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
Number of domains to be returned.
Default: 20
1995 1996 1997 1998 1999 2000 2001 2002 |
# File 'lib/aws-sdk-route53domains/types.rb', line 1995 class ListDomainsRequest < Struct.new( :filter_conditions, :sort_condition, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#sort_condition ⇒ Types::SortCondition
A complex type that contains information about the requested ordering of domains in the returned list.
1995 1996 1997 1998 1999 2000 2001 2002 |
# File 'lib/aws-sdk-route53domains/types.rb', line 1995 class ListDomainsRequest < Struct.new( :filter_conditions, :sort_condition, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |