Class: Aws::Route53Domains::Types::ListDomainsResponse

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-route53domains/types.rb

Overview

The ListDomains response includes the following elements.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#domainsArray<Types::DomainSummary>

A list of domains.



2018
2019
2020
2021
2022
2023
# File 'lib/aws-sdk-route53domains/types.rb', line 2018

class ListDomainsResponse < Struct.new(
  :domains,
  :next_page_marker)
  SENSITIVE = []
  include Aws::Structure
end

#next_page_markerString

If there are more domains than you specified for MaxItems in the request, submit another request and include the value of NextPageMarker in the value of Marker.



2018
2019
2020
2021
2022
2023
# File 'lib/aws-sdk-route53domains/types.rb', line 2018

class ListDomainsResponse < Struct.new(
  :domains,
  :next_page_marker)
  SENSITIVE = []
  include Aws::Structure
end