Class: Aws::Route53Domains::Types::ListOperationsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-route53domains/types.rb

Overview

The ListOperations request includes the following elements.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#markerString

For an initial request for a list of operations, omit this element. If the number of operations that are not yet complete is greater than the value that you specified for MaxItems, you can use Marker to return additional operations. Get the value of NextPageMarker from the previous response, and submit another request that includes the value of NextPageMarker in the Marker element.

Returns:

  • (String)


2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
# File 'lib/aws-sdk-route53domains/types.rb', line 2068

class ListOperationsRequest < Struct.new(
  :submitted_since,
  :marker,
  :max_items,
  :status,
  :type,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

Number of domains to be returned.

Default: 20

Returns:

  • (Integer)


2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
# File 'lib/aws-sdk-route53domains/types.rb', line 2068

class ListOperationsRequest < Struct.new(
  :submitted_since,
  :marker,
  :max_items,
  :status,
  :type,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#sort_byString

The sort type for returned values.

Returns:

  • (String)


2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
# File 'lib/aws-sdk-route53domains/types.rb', line 2068

class ListOperationsRequest < Struct.new(
  :submitted_since,
  :marker,
  :max_items,
  :status,
  :type,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#sort_orderString

The sort order for returned values, either ascending or descending.

Returns:

  • (String)


2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
# File 'lib/aws-sdk-route53domains/types.rb', line 2068

class ListOperationsRequest < Struct.new(
  :submitted_since,
  :marker,
  :max_items,
  :status,
  :type,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#statusArray<String>

The status of the operations.

Returns:

  • (Array<String>)


2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
# File 'lib/aws-sdk-route53domains/types.rb', line 2068

class ListOperationsRequest < Struct.new(
  :submitted_since,
  :marker,
  :max_items,
  :status,
  :type,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#submitted_sinceTime

An optional parameter that lets you get information about all the operations that you submitted after a specified date and time. Specify the date and time in Unix time format and Coordinated Universal time (UTC).

Returns:

  • (Time)


2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
# File 'lib/aws-sdk-route53domains/types.rb', line 2068

class ListOperationsRequest < Struct.new(
  :submitted_since,
  :marker,
  :max_items,
  :status,
  :type,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end

#typeArray<String>

An arrays of the domains operation types.

Returns:

  • (Array<String>)


2068
2069
2070
2071
2072
2073
2074
2075
2076
2077
2078
# File 'lib/aws-sdk-route53domains/types.rb', line 2068

class ListOperationsRequest < Struct.new(
  :submitted_since,
  :marker,
  :max_items,
  :status,
  :type,
  :sort_by,
  :sort_order)
  SENSITIVE = []
  include Aws::Structure
end