Class: Aws::Route53Domains::Types::ListOperationsResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Domains::Types::ListOperationsResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53domains/types.rb
Overview
The ListOperations response includes the following elements.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#next_page_marker ⇒ String
If there are more operations than you specified for
MaxItemsin the request, submit another request and include the value ofNextPageMarkerin the value ofMarker. -
#operations ⇒ Array<Types::OperationSummary>
Lists summaries of the operations.
Instance Attribute Details
#next_page_marker ⇒ String
If there are more operations than you specified for MaxItems in
the request, submit another request and include the value of
NextPageMarker in the value of Marker.
2094 2095 2096 2097 2098 2099 |
# File 'lib/aws-sdk-route53domains/types.rb', line 2094 class ListOperationsResponse < Struct.new( :operations, :next_page_marker) SENSITIVE = [] include Aws::Structure end |
#operations ⇒ Array<Types::OperationSummary>
Lists summaries of the operations.
2094 2095 2096 2097 2098 2099 |
# File 'lib/aws-sdk-route53domains/types.rb', line 2094 class ListOperationsResponse < Struct.new( :operations, :next_page_marker) SENSITIVE = [] include Aws::Structure end |