Class: Aws::Route53Domains::Types::ListPricesRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-route53domains/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#markerString

For an initial request for a list of prices, omit this element. If the number of prices that are not yet complete is greater than the value that you specified for MaxItems, you can use Marker to return additional prices. Get the value of NextPageMarker from the previous response, and submit another request that includes the value of NextPageMarker in the Marker element.

Used only for all TLDs. If you specify a TLD, don't specify a Marker.

Returns:

  • (String)


2130
2131
2132
2133
2134
2135
2136
# File 'lib/aws-sdk-route53domains/types.rb', line 2130

class ListPricesRequest < Struct.new(
  :tld,
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

Number of Prices to be returned.

Used only for all TLDs. If you specify a TLD, don't specify a MaxItems.

Returns:

  • (Integer)


2130
2131
2132
2133
2134
2135
2136
# File 'lib/aws-sdk-route53domains/types.rb', line 2130

class ListPricesRequest < Struct.new(
  :tld,
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#tldString

The TLD for which you want to receive the pricing information. For example. .net.

If a Tld value is not provided, a list of prices for all TLDs supported by Route 53 is returned.

Returns:

  • (String)


2130
2131
2132
2133
2134
2135
2136
# File 'lib/aws-sdk-route53domains/types.rb', line 2130

class ListPricesRequest < Struct.new(
  :tld,
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end