Class: Aws::Route53Domains::Types::OperationLimitExceeded
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Domains::Types::OperationLimitExceeded
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53domains/types.rb
Overview
The number of operations or jobs running exceeded the allowed threshold for the account.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
The number of operations or jobs running exceeded the allowed threshold for the account.
Instance Attribute Details
#message ⇒ String
The number of operations or jobs running exceeded the allowed threshold for the account.
2227 2228 2229 2230 2231 |
# File 'lib/aws-sdk-route53domains/types.rb', line 2227 class OperationLimitExceeded < Struct.new( :message) SENSITIVE = [] include Aws::Structure end |