Class: Aws::Route53Domains::Types::RenewDomainRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Domains::Types::RenewDomainRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53domains/types.rb
Overview
A ‘RenewDomain` request includes the number of years that you want to renew for and the current expiration year.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#current_expiry_year ⇒ Integer
The year when the registration for the domain is set to expire.
-
#domain_name ⇒ String
The name of the domain that you want to renew.
-
#duration_in_years ⇒ Integer
The number of years that you want to renew the domain for.
Instance Attribute Details
#current_expiry_year ⇒ Integer
The year when the registration for the domain is set to expire. This value must match the current expiration date for the domain.
2600 2601 2602 2603 2604 2605 2606 |
# File 'lib/aws-sdk-route53domains/types.rb', line 2600 class RenewDomainRequest < Struct.new( :domain_name, :duration_in_years, :current_expiry_year) SENSITIVE = [] include Aws::Structure end |
#domain_name ⇒ String
The name of the domain that you want to renew.
2600 2601 2602 2603 2604 2605 2606 |
# File 'lib/aws-sdk-route53domains/types.rb', line 2600 class RenewDomainRequest < Struct.new( :domain_name, :duration_in_years, :current_expiry_year) SENSITIVE = [] include Aws::Structure end |
#duration_in_years ⇒ Integer
The number of years that you want to renew the domain for. The maximum number of years depends on the top-level domain. For the range of valid values for your domain, see [Domains that You Can Register with Amazon Route 53] in the *Amazon Route 53 Developer Guide*.
Default: 1
[1]: docs.aws.amazon.com/Route53/latest/DeveloperGuide/registrar-tld-list.html
2600 2601 2602 2603 2604 2605 2606 |
# File 'lib/aws-sdk-route53domains/types.rb', line 2600 class RenewDomainRequest < Struct.new( :domain_name, :duration_in_years, :current_expiry_year) SENSITIVE = [] include Aws::Structure end |