Class: Aws::Route53Domains::Types::TLDInMaintenance

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-route53domains/types.rb

Overview

The top-level domain is currently undergoing maintenance and the request cannot be processed. Try again later.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#messageString

The top-level domain is currently undergoing maintenance and the request cannot be processed. Try again later.

Returns:

  • (String)


2748
2749
2750
2751
2752
2753
# File 'lib/aws-sdk-route53domains/types.rb', line 2748

class TLDInMaintenance < Struct.new(
  :message,
  :tld)
  SENSITIVE = []
  include Aws::Structure
end

#tldString

The top-level domain that is currently undergoing maintenance.

Returns:

  • (String)


2748
2749
2750
2751
2752
2753
# File 'lib/aws-sdk-route53domains/types.rb', line 2748

class TLDInMaintenance < Struct.new(
  :message,
  :tld)
  SENSITIVE = []
  include Aws::Structure
end