Class: Aws::Route53Domains::Types::ViewBillingRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-route53domains/types.rb

Overview

The ViewBilling request includes the following elements.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#endTime

The end date and time for the time period for which you want a list of billing records. Specify the date and time in Unix time format and Coordinated Universal time (UTC).

Returns:

  • (Time)


3302
3303
3304
3305
3306
3307
3308
3309
# File 'lib/aws-sdk-route53domains/types.rb', line 3302

class ViewBillingRequest < Struct.new(
  :start,
  :end,
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#markerString

For an initial request for a list of billing records, omit this element. If the number of billing records that are associated with the current Amazon Web Services account during the specified period is greater than the value that you specified for ‘MaxItems`, you can use `Marker` to return additional billing records. Get the value of `NextPageMarker` from the previous response, and submit another request that includes the value of `NextPageMarker` in the `Marker` element.

Constraints: The marker must match the value of ‘NextPageMarker` that was returned in the previous response.

Returns:

  • (String)


3302
3303
3304
3305
3306
3307
3308
3309
# File 'lib/aws-sdk-route53domains/types.rb', line 3302

class ViewBillingRequest < Struct.new(
  :start,
  :end,
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#max_itemsInteger

The number of billing records to be returned.

Default: 20

Returns:

  • (Integer)


3302
3303
3304
3305
3306
3307
3308
3309
# File 'lib/aws-sdk-route53domains/types.rb', line 3302

class ViewBillingRequest < Struct.new(
  :start,
  :end,
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end

#startTime

The beginning date and time for the time period for which you want a list of billing records. Specify the date and time in Unix time format and Coordinated Universal time (UTC).

Returns:

  • (Time)


3302
3303
3304
3305
3306
3307
3308
3309
# File 'lib/aws-sdk-route53domains/types.rb', line 3302

class ViewBillingRequest < Struct.new(
  :start,
  :end,
  :marker,
  :max_items)
  SENSITIVE = []
  include Aws::Structure
end