Class: Aws::Route53Domains::Types::ListOperationsRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Domains::Types::ListOperationsRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53domains/types.rb
Overview
The ListOperations request includes the following elements.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
For an initial request for a list of operations, omit this element.
-
#max_items ⇒ Integer
Number of domains to be returned.
-
#sort_by ⇒ String
The sort type for returned values.
-
#sort_order ⇒ String
The sort order for returned values, either ascending or descending.
-
#status ⇒ Array<String>
The status of the operations.
-
#submitted_since ⇒ Time
An optional parameter that lets you get information about all the operations that you submitted after a specified date and time.
-
#type ⇒ Array<String>
An arrays of the domains operation types.
Instance Attribute Details
#marker ⇒ String
For an initial request for a list of operations, omit this element.
If the number of operations that are not yet complete is greater
than the value that you specified for MaxItems, you can use
Marker to return additional operations. Get the value of
NextPageMarker from the previous response, and submit another
request that includes the value of NextPageMarker in the Marker
element.
2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 |
# File 'lib/aws-sdk-route53domains/types.rb', line 2068 class ListOperationsRequest < Struct.new( :submitted_since, :marker, :max_items, :status, :type, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
Number of domains to be returned.
Default: 20
2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 |
# File 'lib/aws-sdk-route53domains/types.rb', line 2068 class ListOperationsRequest < Struct.new( :submitted_since, :marker, :max_items, :status, :type, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#sort_by ⇒ String
The sort type for returned values.
2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 |
# File 'lib/aws-sdk-route53domains/types.rb', line 2068 class ListOperationsRequest < Struct.new( :submitted_since, :marker, :max_items, :status, :type, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#sort_order ⇒ String
The sort order for returned values, either ascending or descending.
2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 |
# File 'lib/aws-sdk-route53domains/types.rb', line 2068 class ListOperationsRequest < Struct.new( :submitted_since, :marker, :max_items, :status, :type, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#status ⇒ Array<String>
The status of the operations.
2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 |
# File 'lib/aws-sdk-route53domains/types.rb', line 2068 class ListOperationsRequest < Struct.new( :submitted_since, :marker, :max_items, :status, :type, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#submitted_since ⇒ Time
An optional parameter that lets you get information about all the operations that you submitted after a specified date and time. Specify the date and time in Unix time format and Coordinated Universal time (UTC).
2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 |
# File 'lib/aws-sdk-route53domains/types.rb', line 2068 class ListOperationsRequest < Struct.new( :submitted_since, :marker, :max_items, :status, :type, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |
#type ⇒ Array<String>
An arrays of the domains operation types.
2068 2069 2070 2071 2072 2073 2074 2075 2076 2077 2078 |
# File 'lib/aws-sdk-route53domains/types.rb', line 2068 class ListOperationsRequest < Struct.new( :submitted_since, :marker, :max_items, :status, :type, :sort_by, :sort_order) SENSITIVE = [] include Aws::Structure end |