Class: Aws::Route53Domains::Types::ListPricesRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Domains::Types::ListPricesRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53domains/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#marker ⇒ String
For an initial request for a list of prices, omit this element.
-
#max_items ⇒ Integer
Number of
Pricesto be returned. -
#tld ⇒ String
The TLD for which you want to receive the pricing information.
Instance Attribute Details
#marker ⇒ String
For an initial request for a list of prices, omit this element. If
the number of prices that are not yet complete is greater than the
value that you specified for MaxItems, you can use Marker to
return additional prices. Get the value of NextPageMarker from the
previous response, and submit another request that includes the
value of NextPageMarker in the Marker element.
Used only for all TLDs. If you specify a TLD, don't specify a
Marker.
2130 2131 2132 2133 2134 2135 2136 |
# File 'lib/aws-sdk-route53domains/types.rb', line 2130 class ListPricesRequest < Struct.new( :tld, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#max_items ⇒ Integer
Number of Prices to be returned.
Used only for all TLDs. If you specify a TLD, don't specify a
MaxItems.
2130 2131 2132 2133 2134 2135 2136 |
# File 'lib/aws-sdk-route53domains/types.rb', line 2130 class ListPricesRequest < Struct.new( :tld, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |
#tld ⇒ String
The TLD for which you want to receive the pricing information. For
example. .net.
If a Tld value is not provided, a list of prices for all TLDs
supported by Route 53 is returned.
2130 2131 2132 2133 2134 2135 2136 |
# File 'lib/aws-sdk-route53domains/types.rb', line 2130 class ListPricesRequest < Struct.new( :tld, :marker, :max_items) SENSITIVE = [] include Aws::Structure end |