Class: Aws::Route53Domains::Types::TLDInMaintenance
- Inherits:
-
Struct
- Object
- Struct
- Aws::Route53Domains::Types::TLDInMaintenance
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-route53domains/types.rb
Overview
The top-level domain is currently undergoing maintenance and the request cannot be processed. Try again later.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#message ⇒ String
The top-level domain is currently undergoing maintenance and the request cannot be processed.
-
#tld ⇒ String
The top-level domain that is currently undergoing maintenance.
Instance Attribute Details
#message ⇒ String
The top-level domain is currently undergoing maintenance and the request cannot be processed. Try again later.
2748 2749 2750 2751 2752 2753 |
# File 'lib/aws-sdk-route53domains/types.rb', line 2748 class TLDInMaintenance < Struct.new( :message, :tld) SENSITIVE = [] include Aws::Structure end |
#tld ⇒ String
The top-level domain that is currently undergoing maintenance.
2748 2749 2750 2751 2752 2753 |
# File 'lib/aws-sdk-route53domains/types.rb', line 2748 class TLDInMaintenance < Struct.new( :message, :tld) SENSITIVE = [] include Aws::Structure end |